Learn R Programming

GWsignif (version 1.2.1)

GWsignif-package: Estimating Genome-Wide Significance for Whole Genome Sequencing Studies, Either Single SNP Tests or Region-Based Tests

Description

The correlations and linkage disequilibrium between tests can vary as a function of minor allele frequency thresholds used to filter variants, and also varies with different choices of test statistic for region-based tests. Appropriate genome-wide significance thresholds can be estimated empirically through permutation on only a small proportion of the whole genome.

Arguments

Author

ChangJiang Xu and Celia M.T. Greenwood Maintainer: ChangJiang Xu <changjiang.h.xu@gmail.com>

Details

Package:GWsignif
Type:Package
Version:1.2.1
Date:2016-09-10
License:GLP 2.0 or greater

References

ChangJiang Xu, Ioanna Tachmazidou, Klaudia Walter, Antonio Ciampi, Eleftheria Zeggini, Celia M.T. Greenwood (2014) Estimating genome-wide significance for whole genome sequencing studies. Genetic Epidemiology